## cdist-type__locale(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__locale - Configure locales

## 2. DESCRIPTION

This cdist type allows you to setup locales.

## 3. OPTIONAL PARAMETERS

state
  present or absent, defaults to present

## 4. EXAMPLES

    # Add locale de_CH.UTF-8
    __locale de_CH.UTF-8

    # Same as above, but more explicit
    __locale de_CH.UTF-8 --state present

    # Remove colourful British English
    __locale en_GB.UTF-8 --state absent

## 5. SEE ALSO

- locale(1)
- localedef(1)
- cdist-type(7)

## 6. COPYING

Copyright (C) 2013-2014 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).